@@ -3,11 +3,12 @@
 
 
 # Other Libraries
-from astropy.table import Table
+import click
 import numpy as np
+from astropy.table import Table
 
 
-def load_file(series) -> None:
+def load_file(series) -> int:
     """
     Open file and store time series.
 
@@ -20,9 +21,18 @@ def load_file(series) -> None:
     -------
     None
     """
+    flag = 0
     table = Table.read(series.input)
-    series.time = table['TIME'].data
-    series.time = series.time.astype(series.time.dtype.name)
+    for column in ['TIME', 'time']:
+        try:
+            series.time = table[column].data
+            series.time = series.time.astype(series.time.dtype.name)
+            flag = 0
+            break
+        except KeyError:
+            click.secho(f"Column {column} not found.", fg='red')
+            flag = 1
+    return flag
 
 
 def load_ascii(series) -> None:
@@ -111,7 +121,7 @@ def save_ascii(series) -> None:
     None
     """
     array = np.column_stack((series.bins, series.z2n))
-    table = Table(array, names=('FREQUENCY', 'POTENCY'))
+    table = Table(array, names=('FREQUENCY', 'POWER'))
     table.write(f'{series.output}.txt', format='ascii')
 
 
@@ -129,7 +139,7 @@ def save_csv(series) -> None:
     None
     """
     array = np.column_stack((series.bins, series.z2n))
-    table = Table(array, names=('FREQUENCY', 'POTENCY'))
+    table = Table(array, names=('FREQUENCY', 'POWER'))
     table.write(f'{series.output}.csv', format='csv')
 
 
@@ -147,7 +157,7 @@ def save_fits(series) -> None:
     None
     """
     array = np.column_stack((series.bins, series.z2n))
-    table = Table(array, names=('FREQUENCY', 'POTENCY'))
+    table = Table(array, names=('FREQUENCY', 'POWER'))
     table.write(f'{series.output}.fits', format='fits')
 
 
@@ -165,5 +175,5 @@ def save_hdf5(series) -> None:
     None
     """
     array = np.column_stack((series.bins, series.z2n))
-    table = Table(array, names=('FREQUENCY', 'POTENCY'))
+    table = Table(array, names=('FREQUENCY', 'POWER'))
     table.write(f'{series.output}.hdf5', format='hdf5', compression=True)
